@@ -38,7 +38,7 @@ const xc_func_info_type xc_func_info_mgga_x_mbr = {
   "modified Becke-Roussel by Patra et al",
   XC_FAMILY_MGGA,
   {&xc_ref_Patra2019_19639, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {MBR_N_PAR, mbr_names, mbr_desc, mbr_values, set_ext_params_cpy},
   mgga_x_mbr_init, NULL,
